@@ -19,7 +19,7 @@ from typing import (
 
 import qrcode   # type: ignore
 
-from .utils import extract_file_name_from_url, data_url_to_base64
+from .utils import extract_file_name_from_url, data_url_to_base64, get_json_data
 
 from .type import (
     FileBoxOptionsFile,
@@ -32,6 +32,10 @@ from .type import (
     Metadata, FileBoxType)
 
 from wechaty_puppet.exceptions import WechatyPuppetConfigurationError
+from wechaty_puppet.logger import get_logger
+
+
+logger = get_logger("FileBox")
 
 
 class FileBoxEncoder(json.JSONEncoder):
@@ -49,13 +53,20 @@ class FileBox:
     """
 
     def __init__(self, options: FileBoxOptionsBase):
+        logger.info('init file-box with option<%s>',  options)
 
-        self.mimeType: Optional[str] = None
+        # TODO: will be deprecated after: Dec, 2022
+        self._mimeType: Optional[str] = None
+
+        self._mediaType: Optional[str] = None
 
         self._metadata: Metadata = defaultdict()
 
         self.name = options.name
+
+        # TODO: will be deprecated after: Dec, 2022
         self.boxType: int = options.type.value
+        self.type: int = self.boxType   # type: ignore
 
         if isinstance(options, FileBoxOptionsFile):
             self.localPath = options.path
@@ -83,6 +94,29 @@ class FileBox:
             else:
                 raise WechatyPuppetConfigurationError(
                     f'Base64 File Data Type is invalid, str/bytes is supported')
+    @property
+    def mimeType(self) -> Optional[str]:
+        logger.warn(
+            'mimeType will be deprecated after Dec, 2022, '
+            'we suggest that you should use mediaType property'
+        )
+        return self._mediaType
+    
+    @mimeType.setter
+    def mimeType(self, value: str):
+        logger.warn(
+            'mimeType will be deprecated after Dec, 2022, '
+            'we suggest that you should use mediaType property'
+        )
+        self._mediaType = value
+    
+    @property
+    def mediaType(self) -> Optional[str]:
+        return self._mediaType
+    
+    @mediaType.setter
+    def mediaType(self, value: str):
+        self._mediaType = value
 
     @property
     def metadata(self) -> dict:
@@ -146,11 +180,16 @@ class FileBox:
         dump the file content to json object
         :return:
         """
-        json_data = {}
-        for key in self.__dict__:
-            if getattr(self, key) is not None:
-                json_data[key] = getattr(self,key)
+        # 1. if sending voice file, so check the metadata
+        if self.name.endswith('.sil'):
+            if not self.metadata or not getattr(self.metadata, 'voiceLength'):
+                logger.warn(
+                    'detect that you want to send voice file, '
+                    'but metadata is not valid, please set it, '
+                    'eg: file_box.metadata = {"voiceLength": 2000}'
+                )
 
+        json_data = get_json_data(self)
         data = json.dumps(json_data, cls=FileBoxEncoder, indent=4)
         return data
 
@@ -231,8 +270,17 @@ class FileBox:
         """
         if not os.path.exists(path):
             raise FileNotFoundError(f'{path} file not found')
+        
         if name is None:
             name = os.path.basename(path)
+        
+        # 1. check the audio related code
+        if name.endswith('.silk') or name.endswith('.slk'):
+            logger.warn('detect that you want to send voice file which should be <name>.sil pattern. So we help you rename it.')
+            if name.endswith('.silk'):
+                name = name[:-4] + 'sil'
+            if name.endswith('.slk'):
+                name = name[:-3] + 'slk'
 
         with open(path, 'rb') as f:
             content = base64.b64encode(f.read())
@@ -263,7 +311,7 @@ class FileBox:
         return cls(options)
 
     @classmethod
-    def from_base64(cls: Type[FileBox], base64: bytes, name: str) -> FileBox:
+    def from_base64(cls: Type[FileBox], base64: bytes, name: str = 'base64.dat') -> FileBox:
         """
         create file-box from base64 str
 
@@ -342,7 +390,3 @@ class FileBox:
         file_box.metadata = json_obj['metadata']
 
         return file_box
-
-
-
-
